        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
}
