        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 24 <br>2,3,8,10,12,14,15,16,23,27,28,30,32,33,34,37,38,40,41,44,45,47,48,49';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <strong>control</strong><br>0,1,5,6,7,9,11,13,17,18,19,20,22,29,31,35,42,43,46,50';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260622 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 7 <br>4,21,24,25,26,36,39';}
}
